@@ -37,14 +37,7 @@ from git.index.util import TemporaryFileSwap
 from git.objects import Blob
 from git.util import Actor, cwd, hex_to_bin, rmtree
 
-from test.lib import (
-    TestBase,
-    VirtualEnvironment,
-    fixture,
-    fixture_path,
-    with_rw_directory,
-    with_rw_repo,
-)
+from test.lib import TestBase, VirtualEnvironment, fixture, fixture_path, with_rw_directory, with_rw_repo, PathLikeMock
 
 HOOKS_SHEBANG = "#!/usr/bin/env sh\n"
 
@@ -587,11 +580,15 @@ class TestIndex(TestBase):
                     yield entry.path
                 elif type_id == 1:  # path (PathLike)
                     yield Path(entry.path)
-                elif type_id == 2:  # blob
+                elif type_id == 2:  # path mock (PathLike)
+                    yield PathLikeMock(entry.path)
+                elif type_id == 3:  # path mock in a blob
                     yield Blob(rw_repo, entry.binsha, entry.mode, entry.path)
-                elif type_id == 3:  # BaseIndexEntry
+                elif type_id == 4:  # blob
+                    yield Blob(rw_repo, entry.binsha, entry.mode, entry.path)
+                elif type_id == 5:  # BaseIndexEntry
                     yield BaseIndexEntry(entry[:4])
-                elif type_id == 4:  # IndexEntry
+                elif type_id == 6:  # IndexEntry
                     yield entry
                 else:
                     raise AssertionError("Invalid Type")
@@ -1198,7 +1195,7 @@ class TestIndex(TestBase):
             raise AssertionError("Should have caught a HookExecutionError")
 
     @with_rw_repo("HEAD")
-    def test_index_add_pathlike(self, rw_repo):
+    def test_index_add_pathlib(self, rw_repo):
         git_dir = Path(rw_repo.git_dir)
 
         file = git_dir / "file.txt"
@@ -1206,6 +1203,15 @@ class TestIndex(TestBase):
 
         rw_repo.index.add(file)
 
+    @with_rw_repo("HEAD")
+    def test_index_add_pathlike(self, rw_repo):
+        git_dir = Path(rw_repo.git_dir)
+
+        file = git_dir / "file.txt"
+        file.touch()
+
+        rw_repo.index.add(PathLikeMock(str(file)))
+
     @with_rw_repo("HEAD")
     def test_index_add_non_normalized_path(self, rw_repo):
         git_dir = Path(rw_repo.git_dir)
@@ -1218,6 +1224,48 @@ class TestIndex(TestBase):
 
         rw_repo.index.add(non_normalized_path)
 
+    def test_index_file_v3(self):
+        index = IndexFile(self.rorepo, fixture_path("index_extended_flags"))
+        assert index.entries
+        assert index.version == 3
+        assert len(index.entries) == 4
+        assert index.entries[("init.t", 0)].skip_worktree
+
+        # Write the data - it must match the original.
+        with tempfile.NamedTemporaryFile() as tmpfile:
+            index.write(tmpfile.name)
+            assert Path(tmpfile.name).read_bytes() == Path(fixture_path("index_extended_flags")).read_bytes()
+
+    @with_rw_directory
+    def test_index_file_v3_with_git_command(self, tmp_dir):
+        tmp_dir = Path(tmp_dir)
+        with cwd(tmp_dir):
+            git = Git(tmp_dir)
+            git.init()
+
+            file = tmp_dir / "file.txt"
+            file.write_text("hello")
+            git.add("--intent-to-add", "file.txt")  # intent-to-add sets extended flag
+
+            repo = Repo(tmp_dir)
+            index = repo.index
+
+            assert len(index.entries) == 1
+            assert index.version == 3
+            entry = list(index.entries.values())[0]
+            assert entry.path == "file.txt"
+            assert entry.intent_to_add
+
+            file2 = tmp_dir / "file2.txt"
+            file2.write_text("world")
+            index.add(["file2.txt"])
+            index.write()
+
+            status_str = git.status(porcelain=True)
+            status_lines = status_str.splitlines()
+            assert " A file.txt" in status_lines
+            assert "A  file2.txt" in status_lines
+
 
 class TestIndexUtils:
     @pytest.mark.parametrize("file_path_type", [str, Path])
