@@ -28,7 +28,7 @@ from git.objects.submodule.root import RootModule, RootUpdateProgress
 from git.repo.fun import find_submodule_git_dir, touch
 from git.util import HIDE_WINDOWS_KNOWN_ERRORS, join_path_native, to_native_path_linux
 
-from test.lib import TestBase, with_rw_directory, with_rw_repo
+from test.lib import TestBase, with_rw_directory, with_rw_repo, PathLikeMock
 
 
 @contextlib.contextmanager
@@ -58,6 +58,7 @@ class TestRootProgress(RootUpdateProgress):
         print(op, cur_count, max_count, message)
 
 
+TestRootProgress.__test__ = False
 prog = TestRootProgress()
 
 
@@ -174,6 +175,10 @@ class TestSubmodule(TestBase):
             sma = Submodule.add(rwrepo, sm.name, sm.path)
             assert sma.path == sm.path
 
+            # Adding existing as pathlike
+            sma = Submodule.add(rwrepo, sm.name, PathLikeMock(sm.path))
+            assert sma.path == sm.path
+
             # No url and no module at path fails.
             self.assertRaises(ValueError, Submodule.add, rwrepo, "newsubm", "pathtorepo", url=None)
 
@@ -932,7 +937,7 @@ class TestSubmodule(TestBase):
         csm.repo.index.commit("Have to commit submodule change for algorithm to pick it up")
         assert csm.url == "bar"
 
-        self.assertRaises(
+        self.assertRaises(  # noqa: B017
             Exception,
             rsm.update,
             recursive=True,
